(sec-vcf2zarr-python-api)=
# Python API

Basic usage:
```python
import bio2zarr.vcf as v2z

v2z.convert([vcf_path], vcz_path)
```

## API reference

```{eval-rst}

.. autofunction:: bio2zarr.vcf.convert

```
